config

package
v0.0.0-...-885c207 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 25, 2025 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package config handles the parsing and storage of command-line flags and other application-wide configuration.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Config

type Config struct {
	DryRun            bool
	Help              bool
	IgnoreBreakpoints bool
	Interactive       bool
	JustList          bool
	MarkdownDir       string
	Filter            string
	NoStyling         bool
	Quiet             bool
	Recursive         bool
	StartFrom         string
	MinutesToTimeout  int
	UpdateFile        bool
	Verbose           bool
	Env               []string
	Rootdir           string
}

Config holds all the configuration for the markdown-runner.

func NewConfig

func NewConfig() *Config

NewConfig creates a new Config object and parses the command-line flags.

Jump to